16.118. cdist-type__postgres_database(7) — cdist 6.1.1 documentation

# 16.118. cdist-type__postgres_database(7)

## 16.118.1. NAME

cdist-type__postgres_database - Create/drop postgres databases

## 16.118.2. DESCRIPTION

This cdist type allows you to create or drop postgres databases.

## 16.118.3. OPTIONAL PARAMETERS

state
  either 'present' or 'absent', defaults to 'present'.
owner
  the role owning this database

## 16.118.4. EXAMPLES

    __postgres_database mydbname --owner mydbusername

## 16.118.5. SEE ALSO

cdist-type__postgres_role(7)

## 16.118.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.118.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.